<?php
/**
 * Functions file for loading scripts and stylesheets.
 *
 * @package Cayon
 * @subpackage Functions
 */

/** Register Canyon Core scripts. */
add_action( 'wp_enqueue_scripts', 'canyon_register_scripts', 1 );

/** Load Canyon Core scripts. */
add_action( 'wp_enqueue_scripts', 'canyon_enqueue_scripts' );

/** Register JavaScript and Stylesheet files for the framework. */
function canyon_register_scripts() {

	/* Register the 'drop-downs' scripts if the current theme supports 'canyon-core-menus'. */
	if ( current_theme_supports( 'canyon-core-menus' ) ) {
		wp_register_script( 'canyon-js-hoverintent', esc_url( trailingslashit( CANYON_JS_URI ) . 'hoverintent.min.js' ), array( 'jquery' ), '5', true );
		wp_register_script( 'canyon-js-superfish', esc_url( trailingslashit( CANYON_JS_URI ) . 'superfish.min.js' ), array( 'jquery' ), '1.4.8', true );
		wp_register_script( 'canyon-js-supersubs', esc_url( trailingslashit( CANYON_JS_URI ) . 'supersubs.min.js' ), array( 'jquery' ), '0.2', true );
		wp_register_script( 'canyon-js-drop-downs', esc_url( trailingslashit( CANYON_JS_URI ) . 'drop-downs.js' ), array( 'jquery' ), '1.0', true );
	}
	
	/** Register '960.css' for grid. */
	wp_register_style( 'canyon-css-960', esc_url( trailingslashit( CANYON_CSS_URI ) . '960.css' ) );
}

/** Tells WordPress to load the scripts needed for the framework using the wp_enqueue_script() function. */
function canyon_enqueue_scripts() {

	/** Load the comment reply script on singular posts with open comments if threaded comments are supported. */
	if ( is_singular() && get_option( 'thread_comments' ) && comments_open() ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/** Load the 'drop-downs' script if the current theme supports 'canyon-drop-downs'. */
	if ( current_theme_supports( 'canyon-core-menus' ) ) {
		wp_enqueue_script( 'canyon-js-hoverintent' );
		wp_enqueue_script( 'canyon-js-superfish' );
		wp_enqueue_script( 'canyon-js-supersubs' );
		wp_enqueue_script( 'canyon-js-drop-downs' );
	}
	
	/** Load '960.css' for grid. */
	wp_enqueue_style( 'canyon-css-960' );
}

/** Analytic Code */
add_action( 'wp_footer', 'canyon_analytic_code_init' );
function canyon_analytic_code_init() {
	
	$canyon_options = canyon_get_settings();
	
	if( $canyon_options['canyon_analytic'] == 1 ) :	
	echo htmlspecialchars_decode ( $canyon_options['canyon_analytic_code'] );	
	echo '<!-- end analytic-code -->';	
	endif;

}
?>